==> huaweicloudsdkworkspaceapp-3.1.142-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/create_order_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateOrderReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resources': 'list[Resource]',
        'type': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'type': 'type'
    }

    def __init__(self, resources=None, type=None):
        """CreateOrderReq

        The model defined in huaweicloud sdk

        :param resources: 包周期资源对象。
        :type resources: list[:class:`huaweicloudsdkworkspaceapp.v1.Resource`]
        :param type: createApps【添加云应用】。
        :type type: str
        """
        
        

        self._resources = None
        self._type = None
        self.discriminator = None

        self.resources = resources
        self.type = type

    @property
    def resources(self):
        """Gets the resources of this CreateOrderReq.

        包周期资源对象。

        :return: The resources of this CreateOrderReq.
        :rtype: list[:class:`huaweicloudsdkworkspaceapp.v1.Resource`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this CreateOrderReq.

        包周期资源对象。

        :param resources: The resources of this CreateOrderReq.
        :type resources: list[:class:`huaweicloudsdkworkspaceapp.v1.Resource`]
        """
        self._resources = resources

    @property
    def type(self):
        """Gets the type of this CreateOrderReq.

        createApps【添加云应用】。

        :return: The type of this CreateOrderReq.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateOrderReq.

        createApps【添加云应用】。

        :param type: The type of this CreateOrderReq.
        :type type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOrderReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspaceapp-3.1.156-py2.py3-none-any.whl: huaweicloudsdkworkspaceapp/v1/model/create_order_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateOrderReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'resources': 'list[Resource]',
        'type': 'str'
    }

    attribute_map = {
        'resources': 'resources',
        'type': 'type'
    }

    def __init__(self, resources=None, type=None):
        r"""CreateOrderReq

        The model defined in huaweicloud sdk

        :param resources: 包周期资源对象。
        :type resources: list[:class:`huaweicloudsdkworkspaceapp.v1.Resource`]
        :param type: createApps【添加云应用】。
        :type type: str
        """
        
        

        self._resources = None
        self._type = None
        self.discriminator = None

        self.resources = resources
        self.type = type

    @property
    def resources(self):
        r"""Gets the resources of this CreateOrderReq.

        包周期资源对象。

        :return: The resources of this CreateOrderReq.
        :rtype: list[:class:`huaweicloudsdkworkspaceapp.v1.Resource`]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        r"""Sets the resources of this CreateOrderReq.

        包周期资源对象。

        :param resources: The resources of this CreateOrderReq.
        :type resources: list[:class:`huaweicloudsdkworkspaceapp.v1.Resource`]
        """
        self._resources = resources

    @property
    def type(self):
        r"""Gets the type of this CreateOrderReq.

        createApps【添加云应用】。

        :return: The type of this CreateOrderReq.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this CreateOrderReq.

        createApps【添加云应用】。

        :param type: The type of this CreateOrderReq.
        :type type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOrderReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
